get_ukgeom: Create a local copy of uk shape file

Description Usage Value

View source: R/get_ukgeom.R

Description

This function will attempt to create a local copy of the uk shape file such that you can make sure that you are happy with reading in data from shape files

Usage

1

Value

logical TRUE if the operation was successful


jr-packages/jrSpatial documentation built on Sept. 23, 2020, 2:31 p.m.