This function will attempt to create a local copy of the uk shape file such that you can make sure that you are happy with reading in data from shape files
1 |
logical TRUE if the operation was successful
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.